package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.InitialDockerInfo;
import org.springframework.data.repository.query.Param;

import java.util.List;
import java.util.Map;

/**
 * 容器监控信息Mapper接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface InitialDockerInfoMapper 
{
    /**
     * 查询容器监控信息
     * 
     * @param autoId 容器监控信息主键
     * @return 容器监控信息
     */
    public InitialDockerInfo selectInitialDockerInfoById(Long autoId);

    /**
     * 查询容器监控信息列表
     * 
     * @param initialDockerInfo 容器监控信息
     * @return 容器监控信息集合
     */
    public List<InitialDockerInfo> selectInitialDockerInfoList(InitialDockerInfo initialDockerInfo);

    /**
     * 新增容器监控信息
     * 
     * @param initialDockerInfo 容器监控信息
     * @return 结果
     */
    public int insertInitialDockerInfo(InitialDockerInfo initialDockerInfo);

    /**
     * 修改容器监控信息
     * 
     * @param initialDockerInfo 容器监控信息
     * @return 结果
     */
    public int updateInitialDockerInfo(InitialDockerInfo initialDockerInfo);

    /**
     * 删除容器监控信息
     * 
     * @param autoId 容器监控信息主键
     * @return 结果
     */
    public int deleteInitialDockerInfoById(Long autoId);

    /**
     * 批量删除容器监控信息
     * 
     * @param autoId 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialDockerInfoByIds(Long[] autoId);

    int batchInsertInitialDockerInfo(@Param("list") List<InitialDockerInfo> list);

    /**
     * 容器基础信息
     * @param initialDockerInfo
     * @return
     */
    InitialDockerInfo getDockerDetailsMsg(InitialDockerInfo initialDockerInfo);

    /**
     * 获取指定服务器的容器id
     * @param initialDockerInfo
     * @return
     */
    List<Map> getAllDockerId(InitialDockerInfo initialDockerInfo);
}
